@@ -22,5 +22,11 @@ char *so_get_last_error();
 so_SO *so_SO_read(char *filename);
 int so_SO_write(so_SO *self, char *filename, int pretty);
 so_SOBlock *so_SO_get_SOBlock_from_name(so_SO *self, char *name);
+so_Table *so_SO_all_population_estimates(so_SO *self);
+so_Table *so_SO_all_standard_errors(so_SO *self);
+int so_SO_is_ruv_parameter(so_SO *self, const char *name);
+int so_SO_is_structural_parameter(so_SO *self, const char *name);
+int so_SO_is_correlation_parameter(so_SO *self, const char *name);
+char *so_SO_random_variable_from_variability_parameter(so_SO *self, const char *name);
 
 #endif
